Enum gnss_rtk::SolverType
source · pub enum SolverType {
SPP,
PPP,
}Variants
SPP
SPP : code based and approximated models aiming a metric resolution.
PPP
PPP : phase + code based, the ultimate solver aiming a millimetric resolution.